#!/usr/bin/env bash

### This file contains some common variables
### used by scripts from ${BASE_DIR}/bin/

# Use script full name to extract project base directory
# ${BASH_SOURCE[0]} works even when script is sourced (via . or source) while ${0} doesnt
BASE_DIR=$( dirname $( dirname $( readlink -f ${BASH_SOURCE[0]} ) ) )
#~ BASE_DIR=$( dirname $(dirname $(readlink -f ${0}) ) )
#~ BASE_DIR=$( dirname $( dirname $( realpath ${BASH_SOURCE[0]} ) ) )
#~ BASE_DIR=$(dirname $( dirname $(realpath ${0}) ))
echo -e "BASE_DIR=[${BASE_DIR}]"


# Directory on the host system where Dockerfile is stored
DOCKERFILE_DIR="${BASE_DIR}/docker"

# Docker image name:tag
# used with docker build/run ${DOCKER_IMAGE_TAG}
DOCKER_IMAGE_TAG="electools:electools"

# Docker container name
# used with docker run --name ${DOCKER_CONTAINER_NAME}
DOCKER_CONTAINER_NAME="electools_running"

# Name of user inside Docker container
#~ DOCKER_USERNAME="$(id -u --name)"
DOCKER_USERNAME="user"


# Mountpoint (inside docker container)
# for volume with ElecTools soruce code
# which is mounted in ro mode
# used with docker run -v ${HOST_SRC_DIR}:${DOCKER_SRC_DIR}:rw
HOST_SRC_DIR="${BASE_DIR}"
DOCKER_SRC_DIR="/home/${DOCKER_USERNAME}/electools_src"

# Mountpoint (inside docker container)
# for volume with ElecTools cmake build
# which is mounted in rw mode
# used with docker run -v ${HOST_BUILD_DIR}:${DOCKER_BUILD_DIR}:rw
HOST_BUILD_DIR="/tmp/${USER}/electools_build"
DOCKER_BUILD_DIR="/home/${DOCKER_USERNAME}/electools_build"

DOCKER_OPENBABEL_BUILD_DIR="${DOCKER_BUILD_DIR}/openbabel"
DOCKER_ELECTOOLS_BUILD_DIR="${DOCKER_BUILD_DIR}/electools"


# Mountpoint (inside docker container)
# for volume with work results (output)
# which is mounted in rw mode
# used with  docker run -v ${HOST_RES_DIR}:${DOCKER_RES_DIR}:rw
HOST_RES_DIR="/${HOME}/electools_output"
DOCKER_RES_DIR="/home/${DOCKER_USERNAME}/electools_output"


# Mountpoint (inside docker container)
# for volume with scripts (tools) dir
# which is mounted in ro mode
# used with  docker run -v ${HOST_TOOLS_DIR}:${DOCKER_TOOLS_DIR}:rw
HOST_TOOLS_DIR="/${HOME}/tools"
DOCKER_TOOLS_DIR="/home/${DOCKER_USERNAME}/tools"


# Docker workdir (inside docker container),
# used with $ docker run --workdir ${DOCKER_WORKDIR}
DOCKER_WORKDIR="${DOCKER_RES_DIR}"


# Dir (inside docker container)
# for ElecTools installation
# used with cmake -DCMAKE_INSTALL_PREFIX="${DOCKER_INSTALL_DIR}"
DOCKER_INSTALL_DIR="/usr/local"


# CMake variables
# ON/OFF ElecTools Python and Perl bindings
# OFF by default at the moment due to some bindings build and runtime errors
ET_PYTHON_BINDINGS=ON
ET_PERL_BINDINGS=OFF

# CMake variables
# ON/OFF openbabel Python bindings
OB_PYTHON_BINDINGS=ON
