#!/bin/bash
#
# 1. No argument - default image action (CMD from Dockerfile)
# Example: bin/run_docker_image.sh
#
# 2. /bin/bash argument - just /bin/bash :)
# Example: bin/run_docker_image.sh /bin/bash
#
# 3. any other argument is passed through "/bin/bash -c ..." to the container
# Example: bin/run_docker_image.sh "/opt/electools/bin/build.sh && ctest"
#
#

. "$(dirname "${BASH_SOURCE[0]}")/env_vars.sh" ### import common variables

CUSTOM_DOCKER_CMD=""
if [[ "${1}" != "" ]] ; then
	if [[ "${1}" == "/bin/bash" ]] ; then
		CUSTOM_DOCKER_CMD="${1}"
	else
		CUSTOM_DOCKER_CMD="/bin/bash -c \"${1}\""
	fi
fi

echo -e "\n\tREFRESHING DOCKER IMAGE"
bash "${BASE_DIR}"/bin/prepare_docker_image.sh
echo -e "\n\tDONE"

mkdir -p "${HOST_BUILD_DIR}"
mkdir -p "${HOST_RES_DIR}"

echo -e "\n\tRUNNING DOCKER IMAGE"
docker run --rm \
	-v "${BASE_DIR}:${DOCKER_SRC_DIR}:ro" \
	-v "${HOST_BUILD_DIR}:${DOCKER_BUILD_DIR}:rw" \
	-v "${HOST_RES_DIR}:${DOCKER_RES_DIR}:rw" \
	--name "${DOCKER_CONTAINER_NAME}" \
	--workdir "${DOCKER_WORKDIR}" \
	--user "$(id -u):$(id -g)" \
	--interactive --tty \
	"${DOCKER_IMAGE_TAG}" \
	${CUSTOM_DOCKER_CMD}

echo -e "\n\tDONE"
